RegisterDescriptor

Struct RegisterDescriptor 

pub struct RegisterDescriptor<'a> {
    pub name: String,
    pub feature: Option<String>,
    /* private fields */
}
Wrapper structure for a qemu_plugin_register_descriptor

Safety

This structure is safe to use as long as the pointer is valid. The pointer is always opaque, and therefore may not be dereferenced.

Fields

name: String

The register name

feature: Option<String>

Optional feature descriptor

Implementations

Source

impl<'a> RegisterDescriptor<'a>

pub fn read(&self) -> Result<Vec<u8>>

Read a register value

This must only be called in a callback which has been registered with CallbackFlags::QEMU_PLUGIN_CB_R_REGS or CallbackFlags::QEMU_PLUGIN_CB_RW_REGS, otherwise it will fail.

pub fn write(&self, data: &mut [u8]) -> Result<()>

Read a register value

This must only be called in a callback which has been registered with CallbackFlags::QEMU_PLUGIN_CB_RW_REGS, otherwise it will fail.