pub struct RegisterDescriptor<'a> {
pub name: String,
pub feature: Option<String>,
/* private fields */
}Expand description
Wrapper structure for a qemu_plugin_register_descriptor
Safety
This structure is safe to use as long as the pointer is valid. The pointer is always opaque, and therefore may not be dereferenced.
Fields
name: StringThe register name
feature: Option<String>Optional feature descriptor
Implementations